import { ISchema } from './model/ISchema';
import * as i0 from "@angular/core";
export declare abstract class SchemaValidatorFactory {
    abstract createValidatorFn(schema: any): (value: any) => any;
    abstract getSchema(schema: any, ref: any): any;
    /**
     * Override this method to reset the schema validator instance.<br/>
     * This may be required since some schema validators keep a deep copy<br/>
     * of your schemas and changes at runtime are not recognized by the schema validator.<br/>
     * In this method you should either re-instantiate the schema validator or
     * clear its cache.<br/>
     * Example of re-instantiating schema validator
     * <code>
     *     reset(){
     *         this.zschema = new ZSchema({})
     *     }
     * </code>
     * <br/>
     * Since this method it self does nothing there is <br/>
     * no need to call the <code>super.reset()</code>
     */
    reset(): void;
    /**
     * Override this method if the validator instance supports compiling a schema an resolve all refs and defs.
     * @param schema The schema to be compiled and get its refs, deps, etc. resolved
     * @returns The compiled schema. Per default it does simply return the give schema.
     */
    compile(schema: any): any;
}
export declare class ZSchemaValidatorFactory extends SchemaValidatorFactory {
    protected zschema: any;
    constructor();
    private createSchemaValidator;
    reset(): void;
    compile(schema: any): any;
    createValidatorFn(schema: ISchema): (value: any) => {
        [key: string]: boolean;
    };
    getSchema(schema: any, ref: string): any;
    private denormalizeRequiredPropertyPaths;
    private getDefinition;
    static ɵfac: i0.ɵɵFactoryDeclaration<ZSchemaValidatorFactory, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ZSchemaValidatorFactory>;
}
